@@ -40,6 +40,7 @@ pub struct InteractionMember {
     /// Member's guild avatar.
     #[serde(skip_serializing_if = "Option::is_none")]
     pub avatar: Option<String>,
+    pub communication_disabled_until: Option<Timestamp>,
     pub joined_at: Timestamp,
     pub nick: Option<String>,
     /// Whether the user has yet to pass the guild's Membership Screening
@@ -95,6 +96,7 @@ mod tests {
                 UserId::new(300).expect("non zero"),
                 InteractionMember {
                     avatar: None,
+                    communication_disabled_until: None,
                     joined_at,
                     nick: None,
                     pending: false,
@@ -140,6 +142,7 @@ mod tests {
                     kind: MessageType::Regular,
                     member: Some(PartialMember {
                         avatar: None,
+                        communication_disabled_until: None,
                         deaf: false,
                         joined_at,
                         mute: false,
@@ -243,8 +246,10 @@ mod tests {
                 Token::Str("300"),
                 Token::Struct {
                     name: "InteractionMember",
-                    len: 5,
+                    len: 6,
                 },
+                Token::Str("communication_disabled_until"),
+                Token::None,
                 Token::Str("joined_at"),
                 Token::Str("2021-08-10T12:18:37.000000+00:00"),
                 Token::Str("nick"),
@@ -317,8 +322,10 @@ mod tests {
                 Token::Some,
                 Token::Struct {
                     name: "PartialMember",
-                    len: 7,
+                    len: 8,
                 },
+                Token::Str("communication_disabled_until"),
+                Token::None,
                 Token::Str("deaf"),
                 Token::Bool(false),
                 Token::Str("joined_at"),
