@@ -35,6 +35,7 @@ mod tests {
 
         let value = MemberAdd(Member {
             avatar: None,
+            communication_disabled_until: None,
             deaf: false,
             guild_id: GuildId::new(1).expect("non zero"),
             joined_at,
@@ -68,8 +69,10 @@ mod tests {
                 Token::NewtypeStruct { name: "MemberAdd" },
                 Token::Struct {
                     name: "Member",
-                    len: 8,
+                    len: 9,
                 },
+                Token::Str("communication_disabled_until"),
+                Token::None,
                 Token::Str("deaf"),
                 Token::Bool(false),
                 Token::Str("guild_id"),
