@@ -17,18 +17,18 @@ pub enum AuditLogChangeKey {
     AfkTimeout,
     /// Allowed permissions of a permission overwrite target.
     Allow,
-    /// Thread was archived or unarchived.
-    Archived,
     /// ID of an application.
     ApplicationId,
+    /// Thread was archived or unarchived.
+    Archived,
     /// Asset of a sticker.
     ///
     /// Empty string.
     Asset,
-    /// Availability of a sticker.
-    Available,
     /// Auto archive duration of a thread.
     AutoArchiveDuration,
+    /// Availability of a sticker.
+    Available,
     /// Hash of an avatar.
     AvatarHash,
     /// Hash of a guild banner.
@@ -55,6 +55,8 @@ pub enum AuditLogChangeKey {
     DiscoverySplashHash,
     /// Whether emoticons are enabled.
     EnableEmoticons,
+    /// Entity type of guild scheduled event was changed.
+    EntityType,
     /// Behavior of the expiration of an integration.
     ExpireBehavior,
     /// Grace period of the expiration of an integration.
@@ -73,6 +75,8 @@ pub enum AuditLogChangeKey {
     Id,
     /// ID of the user who created an invite.
     InviterId,
+    /// Channel ID for a scheduled event changed.
+    Location,
     /// Thread was locked or unlocked.
     Locked,
     /// Maximum age of an invite.
@@ -89,10 +93,14 @@ pub enum AuditLogChangeKey {
     Name,
     /// Nickname of a member.
     Nick,
+    /// Whether a channel is NSFW.
+    Nsfw,
     /// NSFW level of a guild.
     NsfwLevel,
     /// ID of the owner of a guild.
     OwnerId,
+    /// Permission overwrites on a channel changed.
+    PermissionOverwrites,
     /// Default permissions of a role.
     Permissions,
     /// Position of an entity such as a channel or role.
@@ -107,6 +115,8 @@ pub enum AuditLogChangeKey {
     PublicUpdatesChannelId,
     /// Ratelimit per user in a textual channel.
     RateLimitPerUser,
+    /// Region of a guild changed.
+    Region,
     /// Role added to a user.
     #[serde(rename = "$add")]
     RoleAdded,
@@ -117,6 +127,8 @@ pub enum AuditLogChangeKey {
     RulesChannelId,
     /// Hash of a guild's splash.
     SplashHash,
+    /// Status of guild scheduled event was changed.
+    Status,
     /// ID of a guild's system channel.
     SystemChannelId,
     /// Related emoji of a sticker.
@@ -184,6 +196,7 @@ impl AuditLogChangeKey {
             Self::Description => "description",
             Self::DiscoverySplashHash => "discovery_splash_hash",
             Self::EnableEmoticons => "enable_emoticons",
+            Self::EntityType => "entity_type",
             Self::ExpireBehavior => "expire_behavior",
             Self::ExpireGracePeriod => "expire_grace_period",
             Self::ExplicitContentFilter => "explicit_content_filter",
@@ -193,6 +206,7 @@ impl AuditLogChangeKey {
             Self::IconHash => "icon_hash",
             Self::Id => "id",
             Self::InviterId => "inviter_id",
+            Self::Location => "location",
             Self::Locked => "locked",
             Self::MaxAge => "max_age",
             Self::MaxUses => "max_uses",
@@ -201,8 +215,10 @@ impl AuditLogChangeKey {
             Self::Mute => "mute",
             Self::Name => "name",
             Self::Nick => "nick",
+            Self::Nsfw => "nsfw",
             Self::NsfwLevel => "nsfw_level",
             Self::OwnerId => "owner_id",
+            Self::PermissionOverwrites => "permission_overwrites",
             Self::Permissions => "permissions",
             Self::Position => "position",
             Self::PreferredLocale => "preferred_locale",
@@ -210,10 +226,12 @@ impl AuditLogChangeKey {
             Self::PruneDeleteDays => "prune_delete_days",
             Self::PublicUpdatesChannelId => "public_updates_channel_id",
             Self::RateLimitPerUser => "rate_limit_per_user",
+            Self::Region => "region",
             Self::RoleAdded => "$add",
             Self::RoleRemoved => "$remove",
             Self::RulesChannelId => "rules_channel_id",
             Self::SplashHash => "splash_hash",
+            Self::Status => "status",
             Self::SystemChannelId => "system_channel_id",
             Self::Tags => "tags",
             Self::Temporary => "temporary",
