@@ -25,7 +25,7 @@ mod tests {
             bot: None,
             description: "Friendship is Magic".to_string(),
             icon: None,
-            id: ApplicationId(123),
+            id: ApplicationId::new(123).expect("non zero"),
             name: "Twilight".to_string(),
             summary: "A cool pony".to_string(),
         };
@@ -63,10 +63,10 @@ mod tests {
                 avatar: None,
                 banner: None,
                 bot: false,
-                discriminator: "0001".to_owned(),
+                discriminator: 1,
                 email: None,
                 flags: None,
-                id: UserId(2),
+                id: UserId::new(2).expect("non zero"),
                 locale: None,
                 mfa_enabled: None,
                 name: "test".to_owned(),
@@ -77,7 +77,7 @@ mod tests {
             }),
             description: "Friendship is Magic".to_string(),
             icon: None,
-            id: ApplicationId(123),
+            id: ApplicationId::new(123).expect("non zero"),
             name: "Twilight".to_string(),
             summary: "A cool pony".to_string(),
         };
