@@ -18,6 +18,7 @@ pub struct Member {
     /// Member's guild avatar.
     #[serde(skip_serializing_if = "Option::is_none")]
     pub avatar: Option<String>,
+    pub communication_disabled_until: Option<Timestamp>,
     pub deaf: bool,
     pub guild_id: GuildId,
     pub joined_at: Timestamp,
@@ -43,6 +44,7 @@ pub struct MemberIntermediary {
     /// Member's guild avatar.
     #[serde(skip_serializing_if = "Option::is_none")]
     pub avatar: Option<String>,
+    pub communication_disabled_until: Option<Timestamp>,
     pub deaf: bool,
     pub joined_at: Timestamp,
     pub mute: bool,
@@ -61,6 +63,7 @@ impl MemberIntermediary {
     pub fn into_member(self, guild_id: GuildId) -> Member {
         Member {
             avatar: self.avatar,
+            communication_disabled_until: self.communication_disabled_until,
             deaf: self.deaf,
             guild_id,
             joined_at: self.joined_at,
@@ -113,6 +116,7 @@ impl<'de> Visitor<'de> for MemberVisitor {
 
         Ok(Member {
             avatar: member.avatar,
+            communication_disabled_until: member.communication_disabled_until,
             deaf: member.deaf,
             guild_id: self.0,
             joined_at: member.joined_at,
@@ -220,6 +224,7 @@ mod tests {
 
         let value = Member {
             avatar: Some("guild avatar".to_owned()),
+            communication_disabled_until: None,
             deaf: false,
             guild_id: GuildId::new(1).expect("non zero"),
             joined_at,
@@ -252,11 +257,110 @@ mod tests {
             &[
                 Token::Struct {
                     name: "Member",
-                    len: 10,
+                    len: 11,
                 },
                 Token::Str("avatar"),
                 Token::Some,
                 Token::Str("guild avatar"),
+                Token::Str("communication_disabled_until"),
+                Token::None,
+                Token::Str("deaf"),
+                Token::Bool(false),
+                Token::Str("guild_id"),
+                Token::NewtypeStruct { name: "GuildId" },
+                Token::Str("1"),
+                Token::Str("joined_at"),
+                Token::Str("2015-04-26T06:26:56.936000+00:00"),
+                Token::Str("mute"),
+                Token::Bool(true),
+                Token::Str("nick"),
+                Token::Some,
+                Token::Str("twilight"),
+                Token::Str("pending"),
+                Token::Bool(false),
+                Token::Str("premium_since"),
+                Token::Some,
+                Token::Str("2021-03-16T14:29:19.046000+00:00"),
+                Token::Str("roles"),
+                Token::Seq { len: Some(0) },
+                Token::SeqEnd,
+                Token::Str("user"),
+                Token::Struct {
+                    name: "User",
+                    len: 7,
+                },
+                Token::Str("accent_color"),
+                Token::None,
+                Token::Str("avatar"),
+                Token::None,
+                Token::Str("banner"),
+                Token::None,
+                Token::Str("bot"),
+                Token::Bool(false),
+                Token::Str("discriminator"),
+                Token::Str("0001"),
+                Token::Str("id"),
+                Token::NewtypeStruct { name: "UserId" },
+                Token::Str("3"),
+                Token::Str("username"),
+                Token::Str("twilight"),
+                Token::StructEnd,
+                Token::StructEnd,
+            ],
+        );
+
+        Ok(())
+    }
+
+    #[test]
+    fn test_guild_member_communication_disabled_until() -> Result<(), TimestampParseError> {
+        let communication_disabled_until = Timestamp::from_str("2021-12-23T14:29:19.046000+00:00")?;
+        let joined_at = Timestamp::from_str("2015-04-26T06:26:56.936000+00:00")?;
+        let premium_since = Timestamp::from_str("2021-03-16T14:29:19.046000+00:00")?;
+
+        let value = Member {
+            avatar: Some("guild avatar".to_owned()),
+            communication_disabled_until: Some(communication_disabled_until),
+            deaf: false,
+            guild_id: GuildId::new(1).expect("non zero"),
+            joined_at,
+            mute: true,
+            nick: Some("twilight".to_owned()),
+            pending: false,
+            premium_since: Some(premium_since),
+            roles: Vec::new(),
+            user: User {
+                accent_color: None,
+                avatar: None,
+                banner: None,
+                bot: false,
+                discriminator: 1,
+                email: None,
+                flags: None,
+                id: UserId::new(3).expect("non zero"),
+                locale: None,
+                mfa_enabled: None,
+                name: "twilight".to_owned(),
+                premium_type: None,
+                public_flags: None,
+                system: None,
+                verified: None,
+            },
+        };
+
+        serde_test::assert_tokens(
+            &value,
+            &[
+                Token::Struct {
+                    name: "Member",
+                    len: 11,
+                },
+                Token::Str("avatar"),
+                Token::Some,
+                Token::Str("guild avatar"),
+                Token::Str("communication_disabled_until"),
+                Token::Some,
+                Token::Str("2021-12-23T14:29:19.046000+00:00"),
                 Token::Str("deaf"),
                 Token::Bool(false),
                 Token::Str("guild_id"),
